@@ -36,7 +36,7 @@ uvloop.install()
 asyncio.run(main())
 """
 
-__version__ = "1.1.2"
+__version__ = "1.1.3"
 
 __all__ = ["looper"]
 
@@ -139,7 +139,7 @@ class Looper:
                 self.print(f"[Cancel Task] {task}")
                 # 测试 task.cancel(msg="测试这个内容")
                 task.cancel(msg=f"looper cancel task {task}")
-        if callable(self.call):
+        if self.call and callable(self.call):
             # if asyncio.iscoroutinefunction(self.call):
             #     loop.run_until_complete(self.call())
             # elif asyncio.iscoroutine(self.call):
